@@ -215,7 +215,7 @@ class MI(Base):
 
     # ========================특정 페이지 관련 함수들=======================
 
-    def get_recent(self, index: str = '') -> dict:
+    def get_recent(self, index: str = '') -> Tuple[str, float]:
         """
         저장된 가장 최근의 값을 반환하는 함수
 
@@ -223,7 +223,7 @@ class MI(Base):
             index (str, optional): 13개의 컬렉션.
 
         Returns:
-            dict: ex - {'date': '2021.07.26', 'value': '1047.63'}
+            tuple: ex - ('2021.07.26', '1047.63')
         """
         if index == '':
             pass
@@ -232,7 +232,7 @@ class MI(Base):
 
         d = self.client[self.db][self.col].find({'date': {'$exists': True}}).sort('date', pymongo.DESCENDING).next()
         del d['_id']
-        return d
+        return d['date'], d['value']
 
     def save(self, mi_dict: dict, index: str = '') -> bool:
         """
@@ -315,10 +315,13 @@ class Corps(Base):
 
     @staticmethod
     def get_all_corps() -> list:
+        """데이터베이스내의 모든 6자리 숫자 코드의 db 명 반환
+
+        """
         return_list = []
-        for col in Base.get_all_db():
-            if utils.is_6digit(col):
-                return_list.append(col)
+        for db in Base.get_all_db():
+            if utils.is_6digit(db):
+                return_list.append(db)
         return sorted(return_list)
 
     @staticmethod
@@ -436,10 +439,29 @@ class C101(Corps):
         return items
 
     def get_recent(self) -> dict:
-        """
-
-        저장된 데이터에서 가장 최근 날짜의 딕셔너리를 반환한다.
+        """저장된 데이터에서 가장 최근 날짜의 딕셔너리를 반환한다.
 
+        Examples:
+            {'date': '2021.08.09',\n
+            '코드': '005930',\n
+            '종목명': '삼성전자',\n
+            '업종': '반도체와반도체장비',\n
+            '주가': '81500',\n
+            '거래량': '15522600',\n
+            'EPS': 4165.0,\n
+            'BPS': 39126.0,\n
+            'PER': 19.57,\n
+            '업종PER': '17.06',\n
+            'PBR': 2.08,\n
+            '배당수익률': '3.67',\n
+            '최고52주': '96800',\n
+            '최저52주': '54000',\n
+            '거래대금': '1267700000000',\n
+            '시가총액': '486537300000000',\n
+            '베타52주': '0.92',\n
+            '발행주식': '5969782550',\n
+            '유통비율': '74.60',\n
+            'intro': '한국 및 CE... DP사업으로 구성됨.'}\n
         """
         try:
             d = self.client[self.db][self.col].find({'date': {'$exists': True}}).sort('date', pymongo.DESCENDING).next()
@@ -589,6 +611,22 @@ class C106(Corps):
         result = self.client[self.db][self.col].insert_one(c106_dict)
         return result.acknowledged
 
+    @staticmethod
+    def cleaning():
+        """모든 corp의 c106컬렉션에서 비정상도큐먼트를 삭제하는 함수.
+
+        c106컬렉션에서 title이 c106y 또는 c106q가 아닌 도큐먼트가 저장되어 있으면 찾아내서 삭제함.
+        """
+        client = pymongo.MongoClient(load_setting()['mongo'])
+        print(f"Mongo addr: {load_setting()['mongo']}")
+        for i, db in enumerate(Corps.get_all_corps()):
+            print(f'{i+1}. Cleaning c106 collection in {db} db.')
+            try:
+                # https://docs.mongodb.com/manual/reference/operator/query/nin/#mongodb-query-op.-nin
+                client[db]['c106'].delete_many({'title': {'$nin': ['c106y', 'c106q']}})
+            except:
+                logger.error(f'Error occurred while delete c106 collection data in {db} db..')
+
 
 class C1034(Corps):
 
@@ -1027,11 +1065,19 @@ class DartByDate(Base):
             raise ValueError(f"Invalid date : {date}(%Y%m%d)")
 
     def save(self, df: pd.DataFrame) -> bool:
+        if df.empty:
+            print('Dataframe is empty..So we will skip saving db..')
+            return False
+
         self.client[self.db][self.col].drop()
         result = self.client[self.db][self.col].insert_many(df.to_dict('records'))
         return result.acknowledged
 
     def get_data(self, title: str = '') -> pd.DataFrame:
+        """저장된 공시 데이터를 데이터프레임으로 반환한다.
+
+        title 인자를 넣으면 타이틀에 해당하는 데이터프레임을 필터링해서 반환한다.
+        """
         try:
             df = pd.DataFrame(list(self.client[self.db][self.col].find())).drop(columns=['_id'])
         except KeyError:
@@ -1089,3 +1135,26 @@ class Noti(Base):
             logger.info(f'Delete noti data before {days_ago} days ago..')
         except:
             logger.error(f'Error occurred while delete noti data..')
+
+
+class EvalByDate(Base):
+    """각 날짜별로 만들어진 eval-report 데이터프레임을 관리하는 클래스
+        """
+
+    def __init__(self, date: str):
+        if utils.isYmd(date):
+            super().__init__(db='eval', col=date)
+        else:
+            raise ValueError(f"Invalid date : {date}(%Y%m%d)")
+
+    def save(self, df: pd.DataFrame) -> bool:
+        self.client[self.db][self.col].drop()
+        result = self.client[self.db][self.col].insert_many(df.to_dict('records'))
+        return result.acknowledged
+
+    def get_data(self) -> pd.DataFrame:
+        try:
+            df = pd.DataFrame(list(self.client[self.db][self.col].find())).drop(columns=['_id'])
+        except KeyError:
+            df = pd.DataFrame()
+        return df
