@@ -44,7 +44,7 @@ def chg_mongo_addr(addr: str):
         before = p_dict['mongo']
         p_dict['mongo'] = addr
         if before != addr:
-            logger.info(f'Change mongo setting : {before} -> {addr}')
+            print(f'Change mongo setting : {before} -> {addr}')
         with open(FULL_PATH, "wb") as fw:
             pickle.dump(p_dict, fw)
     else:
@@ -56,7 +56,7 @@ def chg_sqlite3_path(path: str):
     before = p_dict['sqlite3']
     p_dict['sqlite3'] = path
     if before != path:
-        logger.info(f'Change mongo setting : {before} -> {path}')
+        print(f'Change mongo setting : {before} -> {path}')
     with open(FULL_PATH, "wb") as fw:
         pickle.dump(p_dict, fw)
 
